Photo 111852800, (c) Ben Vasquez, all rights reserved · iNaturalist

- Explore
- Your Observations
- Community
- Identify
- More

Upload

- 0
- 0

## Photo 111852800, (c) Ben Vasquez, all rights reserved

Attribution | © Ben Vasquez all rights reserved
Uploaded by | benvasquez99
Source | iNaturalist
Original | https://www.inaturalist.org/photos/111852800
Associated observations | #### Photos / Sounds #### What Cyprinus carpio European Carp #### Observer benvasquez99 #### Date June 17 , 2018 08:37 AM MDT #### Place Franklin, IA, USA ( Google , OSM ) #### Date Added February 03, 2021 06:14 AM UTC 3 IDs R esearch G rade View
Sizes | small medium large original
Width | 2048
Height | 1536
Bits | 8
Comment |
Image width | 4032
Image length | 3024
Make | samsung
Model | SM-G950U
Orientation | 6
X resolution | 72/1
Y resolution | 72/1
Resolution unit | 2
Software | G950USQS3CRE2
Date time | 2018-06-17 09:37:20 -0700
Ycb cr positioning | 1
Exposure time | 1/1320
F number | 17/10
Exposure program | 2
Iso speed ratings | 50
Date time original | 2018-06-17 09:37:20 -0700
Date time digitized | 2018-06-17 09:37:20 -0700
Shutter speed value | 1/1319
Aperture value | 1.7
Brightness value | 771/100
Exposure bias value | 0/1
Max aperture value | 153/100
Metering mode | 2
Light source | 0
Flash | 0
Focal length | 17/4
User comment | JKJK � � K� j� � � � ��, �� 0� yl��Y���k��� � ����� "��9� � " "w "w "w "w 2w 1" 1" 2w 2w 2w 2w !" � � � " "w "w "w "w 2w 1" 2w 2w 2w 2w 2w 1" � �� � � "w "w "w "w "w 1" 2w Bw 2w 2w 2w 1" � �� � � " "w "w "w "w 1" �� 2w 2w !" !" !" � �� � � � "w "w "w "w �� �� Bw 2w !" !" � � �� � � � "w "w "w "w �� �� 2w !" !" !" � �� �� � � � � "w "w "w �� �� 2w !" !" � � �� �� � � � � "w "w "w �� �� Q3 A" �� �� �� �� �� � � � � " "w �� �� �� q� a� ``
Color space | 1
Pixel x dimension | 4032
Pixel y dimension | 3024
Sensing method | 2
Exposure mode | 0
White balance | 0
Focal length in 35mm film | 26
Scene capture type | 0
Image unique | F12QSJA00SM F12QSKB01SB
GPS time stamp | [(14/1), (37/1), (20/1)]
GPS date stamp | 2018:06:17
Flag This Photo

Member of the iNaturalist Network | Powered by iNaturalist open source software | Documentation for developers